@@ -1,4 +1,4 @@
-# Copyright (C) 2010 Linaro Limited
+# Copyright (C) 2010,2011 Linaro Limited
 #
 # Author: Zygmunt Krynicki <zygmunt.krynicki@linaro.org>
 #
@@ -20,17 +20,4 @@
 Launch Control Tool package
 """
 
-# Chicken-and-egg problem
-__version__ = (0, 4, 1, "final", 0)
-try:
-    import versiontools
-    __version__ = versiontools.Version.from_tuple(__version__)
-except ImportError:
-    pass
-
-
-def get_version():
-    """
-    Return a string representing the version of this package
-    """
-    return str(__version__)
+__version__ = (0, 5, 1, "final", 0)
